Name:           mockito
Version:        3.5.13
Release:        %mkrel 1
Group:          Development/Java
Summary:        Tasty mocking framework for unit tests in Java
License:        MIT
URL:            https://site.mockito.org/
BuildArch:      noarch

# Source tarball and the script to generate it
Source0:        %{name}-%{version}.tar.xz
Source1:        make-%{name}-sourcetarball.sh

# A custom build script to allow building with maven instead of gradle
Source2:        mockito-core.pom

# Mockito expects byte-buddy to have a shaded/bundled version of ASM, but
# we don't bundle in Fedora, so this patch makes mockito use ASM explicitly
Patch0:         use-unbundled-asm.patch

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.bytebuddy:byte-buddy)
BuildRequires:  mvn(net.bytebuddy:byte-buddy-agent)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.assertj:assertj-core)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest-core)
BuildRequires:  mvn(org.objenesis:objenesis)
BuildRequires:  mvn(org.opentest4j:opentest4j)
BuildRequires:  mvn(org.ow2.asm:asm)

%description
Mockito is a mocking framework that tastes really good. It lets you write
beautiful tests with clean & simple API. Mockito doesn't give you hangover
because the tests are very readable and they produce clean verification
errors.

%package javadoc
Summary: Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
%patch0

# Use our custom build script
sed -e 's/@VERSION@/%{version}/' %{SOURCE2} > pom.xml

# OGGi metadata configuration
cat > osgi.bnd <<EOF
Automatic-Module-Name: org.mockito
Bundle-SymbolicName: org.mockito
Bundle-Name: Mockito Mock Library for Java.
Import-Package: junit.*;resolution:=optional,org.junit.*;resolution:=optional,org.hamcrest;resolution:=optional,org.mockito*;version="%{version}",*
Private-Package: org.mockito.*
-removeheaders: Bnd-LastModified,Include-Resource,Private-Package
EOF

# Compatibility alias
%mvn_alias org.%{name}:%{name}-core org.%{name}:%{name}-all

%build
%mvn_build -- -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install

%files -f .mfiles
%license LICENSE
%doc doc/design-docs/custom-argument-matching.md

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Mon Jan 04 2021 neoclust <neoclust> 3.5.13-1.mga8
+ Revision: 1668531
- New version 3.5.13

* Fri Sep 04 2020 daviddavid <daviddavid> 2.28.2-1.mga8
+ Revision: 1621896
- Update to version 2.28.2
- Rebuilt for JDK-11

* Sat Feb 15 2020 umeabot <umeabot> 2.23.9-2.mga8
+ Revision: 1527521
- Mageia 8 Mass Rebuild

* Wed Jul 17 2019 daviddavid <daviddavid> 2.23.9-1.mga8
+ Revision: 1422269
- Update to latest upstream version 2.23.9
- Switch to maven build system using a custom pom to avoid a dep on gradle
- Re-add compatibility alias for 'mockito-all'
- Set the source encoding for the build

* Wed Dec 12 2018 daviddavid <daviddavid> 1.10.19-12.mga7
+ Revision: 1340808
- Remove bundled minified js from javadoc

* Wed Sep 19 2018 umeabot <umeabot> 1.10.19-11.mga7
+ Revision: 1264456
- Mageia 7 Mass Rebuild

* Fri Apr 29 2016 daviddavid <daviddavid> 1.10.19-10.mga6
+ Revision: 1007715
- Explicitly import more cglib packages in OSGi metadata to prevent mockito
  failing under certain circumstances during Eclipse test suites
- Require hamcrest explicitly in OSGi metadata
+ neoclust <neoclust>
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.10.19-8.mga6
+ Revision: 977340
- First rebuild of the java stack
- sync package mockito with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.9.0-8.mga5
+ Revision: 746821
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.9.0-7.mga5
+ Revision: 682555
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 dmorgan <dmorgan> 1.9.0-6.mga5
+ Revision: 671666
- Fix Require into junit instead of junit4

* Mon Oct 21 2013 umeabot <umeabot> 1.9.0-5.mga4
+ Revision: 537732
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 dmorgan <dmorgan> 1.9.0-4.mga4
+ Revision: 487574
- Patched LocalizedMatcher due to hamcrest update, (bug upstream)

* Sat Jan 12 2013 umeabot <umeabot> 1.9.0-3.mga3
+ Revision: 360178
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 13 2012 dmorgan <dmorgan> 1.9.0-2.mga3
+ Revision: 293363
- Fix sources
- Make mockito an OSGi bundle using upstream bnd config.

* Mon Jul 09 2012 dmorgan <dmorgan> 1.9.0-1.mga3
+ Revision: 269023
- New version 1.9.0

* Thu Aug 11 2011 dmorgan <dmorgan> 1.8.5-1.mga2
+ Revision: 132701
- Clean spec file
+ gil <gil>
- edit spec file
- imported package mockito


* Thu Jun 30 2011 gil <gil> 1.8.5-0.%%mkrel
- initial rpm